##########################################
#### Quiz question generator function ####
##########################################
# Generate HTML corresponding to one quiz question.
# Arguments:
#  questionHeader: a Shiny HTML tag object that asks the question (typically a "p()" call)
#  questionChoices: a character vector (possibly with MathJax) of quiz answers
#  explanations: a list of tag objects, each of which is a (corresponding) quiz explanations
#  qn: unqiue question number
# Value: an Shiny HTML tag object
quizQuestion = function(quizBankName, questionHeader, questionChoices, explanations, qn) {
  if (length(questionChoices) != length(explanations)) stop("quiz question/answer length mismatch")
  if (!is(questionChoices, "character")) stop("questionChoices must be a character string")
  n = length(questionChoices)
  order = 1:n
  temp = questionChoices[order]
  questionChoices = as.list(LETTERS[1:n])
  names(questionChoices) = temp
  inputId = paste0(quizBankName, "Quiz", qn)
  temp = vector("list", n)
  for (i in 1:n) {
    temp[[i]] = conditionalPanel(paste("input[['", inputId, "']]=='",
                                       questionChoices[i], "'", sep=""),  explanations[order[i]])
  }
  WIDTH.ANSWER = 6; WIDTH.RESPONSE = 6
  return(fluidRow(
    column(width = WIDTH.ANSWER, questionHeader, radioButtons(inputId, label=NULL, questionChoices, selected=NA)),
    do.call(column, c(list(width=WIDTH.RESPONSE), temp))
  ))
} # end quizQuestion()
